@@ -301,6 +301,8 @@ class ETH_IAM_conn:
         hostOrg=None,
         startDate=None,
         endDate=None,
+        deactivationStartDate=None,
+        deactivationEndDate=None,
     ):
         body = {"username": username}
         if host:
@@ -320,6 +322,14 @@ class ETH_IAM_conn:
             body["startDate"] = startDate
         if endDate:
             body["endDate"] = endDate
+        if startDate:
+            body["startDate"] = startDate
+        if deactivationEndDate is not None:
+            body["deactivationEndDate"] = deactivationEndDate
+        if endDate:
+            body["endDate"] = endDate
+        if deactivationStartDate is not None:
+            body["deactivationStartDate"] = deactivationStartDate
 
         guest = Guest(conn=self, data=body, is_new=False)
         guest.save()
