@@ -336,6 +336,14 @@ def extend_guest(ctx, enddate, months, username):
 @click.option(
     "-e", "--endDate", help="End date of guest (YYYY-MM-DD). Default: today+1 year"
 )
+@click.option(
+    "--deactivationStartDate",
+    help='Deactivation start date of guest (YYYY-DD-MM). Set it to "" to remove',
+)
+@click.option(
+    "--deactivationEndDate",
+    help='Deactivation end date of guest (YYYY-MM-DD). Set it to "" to remove',
+)
 @guest.command("update", help="update an existing guest")
 @click.argument("username")
 @click.pass_context
@@ -350,12 +358,17 @@ def update_guest(
     startdate,
     enddate,
     username,
+    deactivationstartdate,
+    deactivationenddate,
 ):
-
     if startdate:
         startdate = to_date(startdate)
     if enddate:
         enddate = to_date(enddate)
+    if deactivationstartdate:
+        deactivationstartdate = to_date(deactivationstartdate)
+    if deactivationenddate:
+        deactivationenddate = to_date(deactivationenddate)
 
     iam = ctx.obj["iam"]
     try:
@@ -369,6 +382,8 @@ def update_guest(
             hostOrg=hostorg,
             startDate=startdate,
             endDate=enddate,
+            deactivationStartDate=deactivationstartdate,
+            deactivationEndDate=deactivationenddate,
         )
         print(json.dumps(guest._data_formatted(), indent=4, sort_keys=True))
     except Exception as exc:
