@@ -182,6 +182,7 @@ class Guest:
             "startDate",
             "endDate",
             "deactivationStartDate",
+            "deactivationEndDate",
             "dateOfBirth",
         ]
         self.conn = conn
@@ -201,7 +202,8 @@ class Guest:
         body = copy.deepcopy(self.data)
         for date_field in self.date_fields:
             if date_field in body:
-                body[date_field] = body[date_field].strftime("%d.%m.%Y")
+                if body[date_field]:
+                    body[date_field] = body[date_field].strftime("%d.%m.%Y")
         return body
 
     def _data_formatted(self):
